@@ -1,10 +1,14 @@
+use thiserror::Error;
 use twilight_model::application::interaction::{ApplicationCommand, Interaction, Ping};
 
 /// The type of the errors returned by the functions in `InteractionTrait`
+#[derive(Error, Debug)]
 pub enum InteractionConversionError {
     /// Returned if `ping` is called on an `Interaction` whose variant isn't `Ping`
+    #[error("Interaction is not ping")]
     NotPing,
     /// Returned if `application_command` is called on an `Interaction` whose variant isn't `ApplicationCommand`
+    #[error("Interaction is not application command")]
     NotApplicationCommand,
 }
 
